@@ -8,6 +8,9 @@ from enex2notion.string_extractor import extract_string
 def parse_table(element):
     rows = _convert_table_into_rows(element)
 
+    if not rows:
+        return None
+
     table = NotionTableBlock(columns=len(rows[0]))
 
     for row in rows:
@@ -22,6 +25,9 @@ def _convert_table_into_rows(table: Tag):
         for t_row in table.find_all("tr")
     ]
 
+    if not rows:
+        return []
+
     # pad rows, since notion can't do colspan
     longest_row = max(len(r) for r in rows)
     for row in rows:
