@@ -6,7 +6,7 @@ from bs4 import NavigableString, Tag
 from enex2notion.notion_blocks import TextProp
 from enex2notion.string_extractor_properties import resolve_string_properties
 
-STANDALONES = ["h1", "h2", "h3", "div"]
+STANDALONES = ("h1", "h2", "h3", "div")
 
 
 def extract_string(tag: Tag) -> TextProp:
